module EerDashboard
  extend ActiveSupport::Concern

  def restrict_to_overtime_eer
    true
  end

  def event_applies?(target, event)
    (target.is_a?(Machine) && (target.id == event.machine_id)) || (target.is_a?(MachineGroup) && target.machines.any? { |m| m.id == event.machine_id })
  end

  def intersect_range(a, b)
    return nil unless a.overlaps?(b)
    ([a.begin, b.begin].compact.max)..([a.end, b.end].compact.min)
  end

  def range_length(range)
    range ? (range.end - range.begin).to_i : 0
  end

  def intersection_length(a, b)
    range_length(intersect_range(a, b))
  end

  def schedule_data
    @_schedule_data ||= RxModule::Communicator::Shifts.active_ranges_between(start_time, end_time)
  end

  def scheduled_range_data
    @scheduled_range_data ||= schedule_data[:ranges].map do |r|
      (r[:start].to_time)..(r[:end].to_time)
    end
  end

  def total_active_time
    schedule_data[:active_seconds]
  end

  def eer_for_range
    return @_eer_events if @_eer_events
    start_time_arel = EerEvent.arel_table[:start_time]
    @_eer_events = EerEvent.where(machine_id: (requested_machines.map { |m| m.id }) + requested_machine_groups.reduce([]) do |bucket, mg|
      bucket + mg.machines.map { |m| m.id }
    end).where(start_time_arel.gteq(start_time).and(start_time_arel.lteq(end_time)))
    if restrict_to_overtime_eer
      time_over_max_arel = EerEvent.arel_table[:time_over_max]
      @_eer_events = @_eer_events.where(time_over_max_arel.gt(0)).or(@_eer_events.where(event_type: 'engineering_lockout'))
    end
    @_eer_events = @_eer_events.all
  end

  def start_time
    raise "Implement start_time"
  end

  def end_time
    raise "Implement end_time"
  end

  def call_time
    @_call_time ||= Time.now
  end
end
