import * as React from "react";
import {observer} from "mobx-react-lite";
import {Card, Grid, makeStyles} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {grey} from "@material-ui/core/colors";

type BlockPickingDataFieldProps = {
    label: string,
    value: string,
    labelSize?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5',
    valueSize?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5',
    hide?: boolean
};

const useStyles = makeStyles((theme) => ({
    card: {
        display: 'flex',
        alignItems: 'center',
        width: "100%",
        height: "100%"
    },
    secondaryLabel: {
        color: grey[600]
    },
    textCenter: {
        textAlign: 'center'
    }
}));

export const BlockPickingDataField: React.FunctionComponent<BlockPickingDataFieldProps> = observer((props) => {
    let {label, value, labelSize, valueSize, hide} = props;
    const classes = useStyles();

    if (hide) {
        return null;
    }

    labelSize = labelSize ? labelSize : 'h5';
    valueSize = valueSize ? valueSize : 'h3';

    return (
        <Card className={classes.card}>
            <Grid container direction="column" alignItems="center">
                <Typography className={classes.textCenter} variant={labelSize}>{label}</Typography>
                <Typography className={classes.textCenter} variant={valueSize}>{value}</Typography>
            </Grid>
        </Card>
    );
});