import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {makeColumn, ModelTable} from "@rx-suite/ui";
import {BlockPickingModel} from "../../../stores/BlockPickingStore";
import {BlockPickingTagModel, BlockPickingTagStore} from "../../../stores/BlockPickingTagStore";
import {Button, createStyles, IconButton, makeStyles, Theme} from "@material-ui/core";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import {faPen} from "@rx-suite/pro-solid-svg-icons";
import {BlockPickingTagDialogComponent} from "../BlockPickingTagDialogComponent";
import {useSnackbar} from "notistack";
import {Model} from "@rx-suite/data";

type BPTagsSettingsTabProps = {
    model: BlockPickingModel
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        button: {
            padding: theme.spacing(1)
        }
    })
);

export const BPTagsSettingsTab: React.FunctionComponent<BPTagsSettingsTabProps> = observer(({model}) => {
    const {enqueueSnackbar} = useSnackbar();

    const [dialogOpen, setDialogOpen] = React.useState(false);
    const [tagModel, setTagModel] = React.useState<BlockPickingTagModel>(BlockPickingTagStore.createModel());

    const handleClose = React.useCallback(()=>{
        setDialogOpen(false);
    }, []);

    const handleOpen = React.useCallback(()=>{
        setDialogOpen(true);
    }, []);

    const handleSubmit = (submitModel: Model) => {
        submitModel.viewModel.block_picking_id = model.id as number;
        if (submitModel.viewModel.regex == "") {
            // NOTE: if regex is an empty string due to the user adding and deleting values from the input field, set it to null
            submitModel.viewModel.regex = null;
        }
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`Tag successfully created`}`, {variant: "success"})
            setDialogOpen(false);
        });
    }

    const editConfig = (rowModel: BlockPickingTagModel) => {
        setTagModel(rowModel);
        setDialogOpen(true);
    }

    const classes = useStyles();
    const columns = React.useMemo(() => {
        return [
            makeColumn('name', t`Name`, "string"),
            makeColumn('tag', t`Tag`, "string"),
            makeColumn('regex', t`Regex`, "string")
        ]
    }, [])

    return (
        <>
            <Button variant="outlined" color="secondary" onClick={handleOpen}>Add Tag</Button>
            <BlockPickingTagDialogComponent model={tagModel} open={dialogOpen} handleSubmit={handleSubmit} handleClose={handleClose}/>
            <ModelTable store={BlockPickingTagStore}
                        columns={columns}
                        defaultFiltered={[{id: "block_picking_id", value: model.id}]}
                        showCreateButton={false}
                        fixedHeight={false}
                        replacementActions={
                            {
                                Edit: (a) =>
                                    <IconButton onClick={() => editConfig(a.model as BlockPickingTagModel)} size={"small"} className={classes.button}>
                                        <FontAwesomeIcon icon={faPen}/>
                                    </IconButton>,
                                Read: () => null
                            }
                        }
                        suppressWrapper
                        noLinkColumns={['name', 'tag', 'regex']}
            />
        </>
    );
});
