import * as React from 'react';
import {makeColumn, ModelTable} from "@rx-suite/ui";
import {StatusColorModel, StatusColorStore} from "../../../stores/StatusColorStore";
import {t} from "@lingui/macro";
import {ColorPicker} from 'material-ui-color';
import {observer} from "mobx-react-lite";
import {createStyles, IconButton, Theme} from "@material-ui/core";
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import {faPen} from "@rx-suite/pro-solid-svg-icons";
import {makeStyles} from "@material-ui/core/styles";
import {StatusColorEditDialog} from "./StatusColorEditDialog";
import {useSnackbar} from "notistack";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        button: {
            padding: theme.spacing(1)
        }
    })
);

export const StatusColorTab: React.FunctionComponent = observer(() => {
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();

    const [dialogOpen, setDialogOpen] = React.useState(false);
    const [selectedStatusColor, setSelectedStatusColor] = React.useState<StatusColorModel>(StatusColorStore.createModel());

    const columns = [
        makeColumn('status_name', t`Machine State`, "string"),
        {
            Header: t`Color`,
            id: 'color',
            accessor: (model: StatusColorModel) => model,
            Cell: (row: { original: StatusColorModel | null | undefined }) => {
                if (!row.original) {
                    return null;
                }
                return <ColorPicker value={row.original.color}  disableAlpha hideTextfield onChange={()=>null}/>
            },
            filterable: false,
            sortable: false,
        }
    ]

    const handleSubmit = React.useCallback((submitModel: StatusColorModel) => {
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`Color successfully updated!`}`, {variant: "success"});
            setDialogOpen(false);
        });
        setDialogOpen(false);
    }, [selectedStatusColor]);

    const handleClickOpen = React.useCallback((colorModel: StatusColorModel) => {
        setSelectedStatusColor(colorModel);
        setDialogOpen(true);
    }, []);

    const handleClose = () => {
        setDialogOpen(false);
    }

    return(
        <React.Fragment>
            <ModelTable store={StatusColorStore}
                        columns={columns}
                        showCreateButton={false}
                        replacementActions={
                            {
                                Edit: ({model}) =>
                                    <IconButton onClick={() => handleClickOpen(model as StatusColorModel)} size={"small"} className={classes.button}>
                                        <FontAwesomeIcon icon={faPen}/>
                                    </IconButton>,
                                Delete: () => null,
                                Read: () => null
                            }
                        }
                        suppressWrapper
                        noLinkColumns={['status_name', 'color']}
            />
            <StatusColorEditDialog model={selectedStatusColor} open={dialogOpen} handleClose={handleClose} handleSubmit={handleSubmit}/>
        </React.Fragment>
    )
});
