import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField, makeColumn, ModelSelect, ModelTable, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {MachineMachineDataPushTargetStore} from "../../stores/MachineMachineDataPushTargetStore";
import {useModalHandler} from "../../hooks/useModalHandler";
import {MachineDataPushTargetModel} from "../../stores/MachineDataPushTargetStore";
import {Divider} from "@material-ui/core";
import Box from "@material-ui/core/Box";
import {ExternalForwardingAddMachineDialog} from "./ExternalForwardingAddMachineDialog";
import {Add} from "@material-ui/icons";

export const ExternalForwardingMachinesTab: React.FunctionComponent = observer(( ) => {
    const [addMachineDialogOpen, handleCloseAddMachine, handleOpenAddMachine] = useModalHandler();
    const model = useModelContext() as MachineDataPushTargetModel;

    const columns = React.useMemo(() => {
        return [
            makeColumn('name', t`Machine Name`, "string"),
        ]
    }, []);

    return (
        <React.Fragment>
            <ModelSelect name={'send_to'}
                         options={
                            [
                                {label: t`All Machines`, value: 'all_machines'},
                                {label: t`Specific Machines`, value: 'specific_machines'}
                            ]
                        }
            />
            {!model.viewModel.isAllMachines &&
                <Box>
                    <Box mb={1} mt={1}>
                        <Divider/>
                    </Box>
                    <ButtonField
                        text={'Add Machine'}
                        onClick={handleOpenAddMachine}
                        color={'secondary'}
                        startIcon={<Add/>}
                    />
                    <ModelTable store={MachineMachineDataPushTargetStore}
                                columns={columns}
                                defaultFiltered={[{ id: 'machine_data_push_target_id', value: model.getId() }]}
                                suppressWrapper
                    />
                    <ExternalForwardingAddMachineDialog
                        model={model}
                        open={addMachineDialogOpen}
                        handleClose={handleCloseAddMachine}
                    />
                </Box>
            }
        </React.Fragment>
    )
})
