import * as React from "react";
import {observer} from "mobx-react-lite";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {grey} from "@material-ui/core/colors";
import {t} from "@lingui/macro";
import {StatusColorStore} from "../../stores/StatusColorStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";

type MachineStateBadgeProps = {
    lastState?: any | null;
    isLoading: boolean
}

const useStyles = makeStyles(() => ({
    badge: {
        margin: '0px 5px',
        padding: '2px 4px',
        borderRadius: '3px',
        backgroundColor: grey[300],
        display: "inline-block"
    },
    badgeCircle: {
        height: '12px',
        width: '12px',
        borderRadius: '12px',
        display: 'inline-block',
        marginRight: '5px'
    },
    typography: {
        display: "inline-block"
    }
}));

export const MachineStateBadge: React.FunctionComponent<MachineStateBadgeProps> = observer(({lastState, isLoading}) => {
    const classes = useStyles();
    const statusColors = StatusColorStore.getAll();
    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;

    const machineState = lastState ? lastState.state.toUpperCase() : t`No Machine State found`;
    const machineStateTime = lastState ? systemSettingModel.printDateTime(new Date(lastState.time)) : undefined;
    const machineStateColor = lastState ? statusColors.find(c => c.status_name == machineState)?.color : undefined;

    const formattedState = isLoading ? t`Loading...` : machineState;
    const stateTime = machineStateTime;

    return (
        <div>
            <Typography variant={'subtitle1'} className={classes.typography}>{t`Current State:`}</Typography>
            <div className={classes.badge}>
                {machineStateColor && <div className={classes.badgeCircle} style={{background: `${machineStateColor}`}}/>}
                {formattedState}
            </div>
            {!isLoading && lastState && <Typography variant={'subtitle1'}>{t`Since:`} {stateTime}</Typography>}
        </div>
    );
});