import * as React from "react";
import {makeStyles, Paper, Typography} from "@material-ui/core";

type SidesPaperDisplayProps = {
    leftDisplay: {
        label: string;
        component: JSX.Element
    };
    rightDisplay: {
        label: string;
        component: JSX.Element
    };
    invertSides?: boolean;
};

const useStyles = makeStyles((theme) => ({
    tables: {
        display: 'flex',
        justifyContent: 'space-around',
        alignItems: 'flex-start'
    },
    table: {
        padding: '0.5rem',
        width: '48%'
    },
    tableTitle: {
        marginBottom: '0.5rem',
        textAlign: 'center'
    }
}));


export const SidesPaperDisplay: React.FunctionComponent<SidesPaperDisplayProps> = ({ leftDisplay, rightDisplay, invertSides }) => {

    // this is a wrapper to display any left and right lens data side by side

    const classes = useStyles();

    const papers = invertSides ? [rightDisplay, leftDisplay] : [leftDisplay, rightDisplay];

    return (<div
        className={classes.tables}
    >
        {papers.map(paper => <Paper
            className={classes.table}
            variant='outlined'
        >
            <Typography
                className={classes.tableTitle}
                variant='h5'
            >
                {paper.label}
            </Typography>
            {paper.component}
        </Paper>)}
    </div>);
};
