import * as React from "react";
import {Tab, TabsProps} from "@material-ui/core";
import {TabPanel} from "./TabPanel";
import {WorkstationTabWrapper} from "@rx-suite/ui";

type TabsContainerProps = {
    tabs: ReadonlyArray<TabInfo>;
    variant?: TabsProps['variant'];
    scrollButtons?: "auto";
};

export type TabInfo = Readonly<{
    label: string;
    component: JSX.Element;
    disabled?: boolean;
    defaultTab?: boolean;
}>;


export const TabsContainer: React.FunctionComponent<TabsContainerProps> = (props) => {

    const { tabs, variant, scrollButtons } = props;

    // create a container that contains a tab for each component provided

    // check if there is a default tab, if not, set the first tab as default
    const defaultTab = tabs.findIndex(tab => tab && !!tab.defaultTab);
    const defaultTabValue = defaultTab === -1 ? 0 : defaultTab;
    const tabsVariant = variant || "fullWidth";

    const [value, setValue] = React.useState<number>(defaultTabValue);

    const handleChange = (event: React.ChangeEvent<{}>, newValue: number) => {
        setValue(newValue);
    };

    return <div>
        <WorkstationTabWrapper
            value={value}
            indicatorColor="primary"
            textColor="primary"
            variant={tabsVariant}
            scrollButtons={scrollButtons || undefined}
            onChange={handleChange}
        >
            {tabs.map((tab, i) => {

                return <Tab key={`tab-${tab.label}-${i}`} label={tab.label} value={i} disabled={!!tab.disabled}/>;
            })}
        </WorkstationTabWrapper>
        {tabs.map((tab, i) => {

            return <TabPanel key={`tab-panel-${tab.label}-${i}`} index={i} value={value}>
                {tab.component}
            </TabPanel>;
        })}
    </div>;
};
