import * as React from 'react';
import ReactTable from "react-table";
import {t} from "@lingui/macro";
import {ProcessParams} from "../../pages/job_history/JobHistoryOperatorForm";

type ProcessParamsTableProps = {
    processParams: ReadonlyArray<ProcessParams> | null;
};


export const ProcessParamsTable: React.FunctionComponent<ProcessParamsTableProps> = ({ processParams }) => {

    // this table only displays the name and the value of the process params

    const tableData: Array<ProcessParams> = (processParams ? processParams.slice() : []);

    const columns = [{
        Header: t`Tag`,
        accessor: 'name',
        filterable: true
    }, {
        Header: t`Value`,
        accessor: 'value'
    }];

    return <ReactTable
        data={tableData}
        columns={columns}
        showPagination={false}
        // provide all of the data to the table,
        // without this, the table could show 30 rows,
        // but only fill 20 rows with data
        defaultPageSize={tableData.length}
        minRows={tableData.length <= 0 ? 10 : tableData.length} // if empty, pad the table with 10 rows
        sortable={false}
    />;
};
