import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelInput, ModelSelect} from "@rx-suite/ui";
import {MachineGroupStore} from "../../../stores/MachineGroupStore";
import {MachineTypeStore} from "../../../stores/MachineTypeStore";

export const MachineGeneralSettingsTab: React.FunctionComponent = observer(() => {
    const machineGroups = MachineGroupStore.getAll();

    const machineGroupOptions = React.useMemo(()=> {
        return machineGroups.sort((a,b) => a.name.localeCompare(b.name)).map(g => {
            return {
                value: g.getId(),
                label: g.name
            }
        })
    }, [MachineGroupStore.models])

    const machineTypesOptions = React.useMemo(()=> {
        const options = [];
        const other = {label: 'Other', options: []};

        MachineTypeStore.models.forEach((type) => {
            let category;
            if(type.category){
                category = options.find(option => option.label == type.category)
                if(!category) {
                    category = {label: type.category, options: []}
                    options.push(category);
                }
            }else {
                category = other;
            }
            category.options.push({label: type.display_name, value: type.getId()})
        });

        options.sort((a,b) => a.label.localeCompare(b.label))

        // Put 'Other' as last in the list
        options.push(other);

        return options;
    }, [MachineGroupStore.models])


    return (
        <React.Fragment>
            <div>
                <ModelInput name={"name"} />
                <ModelSelect loading={MachineTypeStore.isLoading} options={machineTypesOptions} name={"machine_type_id"}/>
                <ModelSelect multiple loading={MachineGroupStore.isLoading} options={machineGroupOptions} name={"machine_group_ids"}/>
            </div>
        </React.Fragment>
    );
});
