import * as React from "react";
import {observer} from "mobx-react-lite";
import {MachineModel, MachineStore} from "../../../stores/MachineStore";
import {CheckboxField, IfTrue, ModelCheckbox, ModelSelect} from "@rx-suite/ui";
import {t} from "@lingui/macro";

type MachineUsageSettingsTabProps = {
    machine: MachineModel;
};

export const MachineUsageSettingsTab: React.FunctionComponent<MachineUsageSettingsTabProps> = observer(({machine}) => {

    const [useAsReject, setUseAsReject] = React.useState(machine.machine_ids.length > 0);
    const handleChangeMarkDeadJobs = React.useCallback((e) => {
        if(!e.target.checked){
            machine.viewModel.machine_ids = [];
        }
        setUseAsReject(e.target.checked);
    }, [machine]);

    const machineOptions =  React.useMemo(()=> {
        return MachineStore.getAll().map((m) => {
            return {
                value: m.getId(),
                label: m.extendedName
            }
        });
    }, [MachineStore.models])

    return (
        <React.Fragment>
            <div>
                <div>
                    <CheckboxField label={t`Use as Kickout Station`} checked={useAsReject} onChange={handleChangeMarkDeadJobs} hint={{title: `Use as Reject Station`, text: t`Set this machine as a reject station. This setting must be enabled to generate a Kickout Report.`}}/>
                </div>
                <IfTrue comparator={useAsReject}>
                    <ModelSelect multiple loading={MachineStore.isLoading} options={machineOptions} name={"machine_ids"} style={{display: useAsReject ? 'block' : 'none'}} hint={{title: t`Handles Reject for Machines`, text: `The selected machines will be used to estimate the throughput of this kickout station. Note this only impacts reporting.`}}/>
                </IfTrue>
                <div>
                    <ModelCheckbox name={"is_conveyor_machine"}
                                    hint={{title: 'Use for Conveyor Routing?', text: 'This machine will only appear in Rx-Routing if this setting is enabled.'}}/>
                </div>
                <div>
                    <ModelCheckbox label={t`Use Box Coater Metrics`}
                                   name={"track_eer_metrics"}
                                   hint={{title: 'Use Box Coater Metrics', text: 'This setting is automatically enabled when a tracking station is created for this machine in Rx-EER.'}}
                                   disabled />
                </div>
                <div>
                    <ModelCheckbox name={"push_target_enabled"}
                                   hint={{title: 'Send Push Targets?', text: 'This machine will send data to the defined push targets when this setting is enabled.'}}/>
                </div>
            </div>
        </React.Fragment>
    );
});
