import * as React from "react";
import {observer} from "mobx-react-lite";
import {FormProps} from "@rx-suite/ui";
import {useSnackbar} from "notistack";
import {CircularProgress, IconButton, makeStyles} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faArchive} from "@rx-suite/pro-solid-svg-icons";
import {errToString, Model} from "@rx-suite/data";
import { t } from "@lingui/macro"
import {MachineModel} from "../../../stores/MachineStore";
import {currentUserCan} from "@rx-suite/stores";

const useStyles = makeStyles(theme => ({
    danger: {
        color: theme.palette.error.main
    }
}));

type ArchiveProps = {
    model: MachineModel;
}

export const ArchiveButton: React.FunctionComponent<ArchiveProps> = observer(({ model }) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles();
     const handleClick = React.useCallback(async () => {
        try {
            let message = t`Are you sure you want to archive?`;

            if(model.is_conveyor_machine){
                message += '\n\n' + t`WARNING: this machine is being used in Rx-Routing. Please also delete it in that module.`;
            }

            await model.archive(message);
        } catch (e) {
            enqueueSnackbar(t`Problem archiving:` + errToString(e), {variant: 'error'});
        }
    }, [model]);

    if(!currentUserCan('Machine', 'Archive')){
        return null;
    }

    return (
        <div>
            {model.updating ? <CircularProgress size={24}/> :
            <IconButton onClick={handleClick}>
                <FontAwesomeIcon icon={faArchive} className={classes.danger}/>
            </IconButton>}
        </div>
    )
})

