import * as React from "react";
import {observer} from "mobx-react-lite";
import {useSnackbar} from "notistack";
import {errToString} from "@rx-suite/data";
import {CircularProgress, IconButton, makeStyles} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faArchive, faTrashRestore} from "@rx-suite/pro-solid-svg-icons";
import {MachineModel} from "../../../stores/MachineStore";
import { t } from "@lingui/macro"
import {currentUserCan} from "@rx-suite/stores";

const useStyles = makeStyles(theme => ({
    danger: {
        color: theme.palette.error.main
    }
}));

type RestoreProps = {
    model: MachineModel;
}

export const RestoreButton: React.FunctionComponent<RestoreProps> = observer(({ model }) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles();
     const handleClick = React.useCallback(async () => {
        try {
            await model.restore(t`Are you sure you want to restore this?`);
            model.viewModel.archived = false;
            model.viewModel.submit();
        } catch (e) {
            enqueueSnackbar(t`Problem restoring:` + errToString(e), {variant: 'error'});
        }
    }, [model]);

     if(!currentUserCan('Machine', 'Archive')){
         return null;
     }

    return (
        <div>
            {model.updating ? <CircularProgress size={24}/> :
            <IconButton onClick={handleClick}>
                <FontAwesomeIcon icon={faTrashRestore} className={classes.danger}/>
            </IconButton>}
        </div>
    )
})