import * as React from "react";
import {observer} from "mobx-react-lite";
import {Button, makeStyles} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faArchive} from "@rx-suite/pro-solid-svg-icons";
import {MachineStore} from "../../../stores/MachineStore";
import  {Trans} from "@lingui/macro";
import {DataStore, Model} from "@rx-suite/data";

const useStyles = makeStyles(theme => ({
    toggleButton: {
        alignSelf: 'start',
        marginLeft: '10px',
    }
}));

type ToggleArchivedProps = {
    store: DataStore<Model>
}

export const ToggleArchivedButton: React.FunctionComponent<ToggleArchivedProps> = observer(({store}) => {

    const classes = useStyles();

    const handleToggle = React.useCallback(async () => {
        const flag = !store.showArchived;

        await store.toggleArchived(flag);
    }, [store.showArchived]);

    let buttonText = <Trans>Hide Archive</Trans>
    if(!store.showArchived){
        buttonText = <Trans>Show Archive</Trans>
    }

    return (
        <Button value="check" variant={'outlined'} startIcon={<FontAwesomeIcon icon={faArchive}/>} onClick={handleToggle} className={classes.toggleButton} color={'primary'}>
            {buttonText}
        </Button>
    )
})