import * as React from 'react';
import {JobStateModel} from "../../../stores/JobStateStore";
import {useEffect, useState} from "react";
import {CircularProgress, makeStyles, Typography} from "@material-ui/core";
import {ProcessParamsTable} from "../../job_history/ProcessParamsTable";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";

type AsyncProcessParamsProps = {
    model: JobStateModel;
};

type ProcessParamsData = ReadonlyArray<Readonly<{ name: string | null, value: string | null}>>;

const useStyles = makeStyles((theme) => ({
    processParamTable: {
        "& .rt-tbody": {
            height: 'unset'
        }
    },
    loadingContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        padding: theme.spacing(2)
    },
    loadingText: {
        marginLeft: theme.spacing(1)
    }
}));

export const AsyncProcessParams: React.FunctionComponent<AsyncProcessParamsProps> = ({ model }) => {

    const classes = useStyles();

    const [processParams, setProcessParams] = useState<ProcessParamsData|null>(null);

    const {enqueueSnackbar} = useSnackbar();

    useEffect(() => {
        const fetchData = async () => {
            const processParamsForJobState = await model.getProcessParams();

            if ('error' in processParamsForJobState) {
                enqueueSnackbar(processParamsForJobState.error, {variant: "error"});
                setProcessParams([]);
                return;
            }

            setProcessParams(processParamsForJobState.process_params);
        };
        fetchData();
    }, []);

    if (!processParams) {
        return <div className={classes.loadingContainer}>
            <CircularProgress />
            <Typography className={classes.loadingText} variant="subtitle1">
                {t`Fetching Data…`}
            </Typography>
        </div>;
    }

    return <div className={classes.processParamTable}>
        <ProcessParamsTable processParams={processParams} />
    </div>;
};
