import * as React from 'react';
import ReactTable from "react-table";
import {t} from "@lingui/macro";
import {EventData} from "../../../stores/EventStore";

type EventDataTableProps = {
    eventData: EventData | null;
};


export const EventDataTable: React.FunctionComponent<EventDataTableProps> = ({ eventData }) => {

    // this table only displays the name and the value of the event data

    const tableData: EventData = (eventData ? eventData.slice() : []);

    const columns = [{
        Header: t`Name`,
        accessor: 'name',
        filterable: true
    }, {
        Header: t`Value`,
        accessor: 'value'
    }];

    return <ReactTable
        data={tableData}
        columns={columns}
        showPagination={false}
        // provide all of the data to the table,
        // without this, the table could show 30 rows,
        // but only fill 20 rows with data
        defaultPageSize={tableData.length}
        minRows={tableData.length <= 0 ? 5 : tableData.length} // if empty, pad the table with 5 rows
        sortable={false}
    />;
};
