import * as React from "react";
import {renderToString} from "react-dom/server";
import {Trans} from "@lingui/macro";
import Box from "@material-ui/core/Box";
import {Divider, Grid, makeStyles, Typography} from "@material-ui/core";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {observer} from "mobx-react-lite";
import classNames from "classnames";
import {BATCH_RUN_COLORS, durationForBatch} from "./batchRunUtilities";

export type BatchRunDatum = {
    name: string;
    state: string;
    x: string;
    y: string[];
    fillColor: string;
    duration: number;
}

type BatchTimelineToolTip = {
    dataPoint: BatchRunDatum | undefined;
}

const useStyles = makeStyles((theme) => ({
    title: {
        fontWeight: 'bold',
        fontSize: '0.9rem'
    },
    text: {
        fontSize: '0.85rem'
    },
    statusWrapper: {
        width: "fit-content",
        fontSize: '0.8rem'
    },
    statusDot: {
        width: '10px',
        height: '10px',
        borderRadius: '5px',
        backgroundColor: 'black'
    },
    listLabel: {
        fontWeight: 'bold',
        marginRight: theme.spacing(1)
    },
}));

const BatchTimelineToolTip: React.FunctionComponent<BatchTimelineToolTip> = observer(({dataPoint}) => {
    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
    const classes = useStyles();

    if(!dataPoint){
        return (
            <Box mb={1} mt={1} ml={1} mr={1}>
                <Trans>no data</Trans>
            </Box>
        )
    }

    return (
        <Box mb={1} mt={1} ml={1} mr={1}>
            <Typography className={classes.title}>{dataPoint.name}</Typography>
            <Divider/>
            <Grid container justifyContent={'space-between'}>
                <Grid container alignItems={'center'} className={classes.statusWrapper}>
                    <Box mr={0.5}>
                        <div className={classNames(classes.statusDot)} style={{backgroundColor: dataPoint.fillColor}}/>
                    </Box>
                    <Typography className={classes.text}>{dataPoint.state.toUpperCase()}</Typography>
                </Grid>
                <Typography className={classes.text}>{durationForBatch(dataPoint.duration)}</Typography>
            </Grid>

            <Grid container justifyContent={'space-between'}>
                <Typography className={classNames(classes.listLabel, classes.text)}>Start:</Typography>
                <Typography className={classes.text}>{systemSettingModel.printDateTime(new Date(dataPoint.y[0]))}</Typography>
            </Grid>
            <Grid container justifyContent={'space-between'}>
                <Typography className={classNames(classes.listLabel, classes.text)}>End:</Typography>
                <Typography className={classes.text}>{systemSettingModel.printDateTime(new Date(dataPoint.y[1]))}</Typography>
            </Grid>
        </Box>
    )
});

export const useBatchTimelineToolTip = (dataPoint: BatchRunDatum | undefined) => {
    // Apex Chart custom tool tip cannot take direct React components
    return renderToString(
        <BatchTimelineToolTip dataPoint={dataPoint}/>
    )
}
