import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ModelForm, ModelInput, SelectField} from '@rx-suite/ui';
import {TabsContainer} from "../../../components/generic/TabsContainer";
import {t} from "@lingui/macro"
import {ExternalForwardingEndpointsTab} from "../../../components/data_forwarding_external_targets/ExternalForwardingEndpointsTab";
import {ExternalForwardingMachinesTab} from "../../../components/data_forwarding_external_targets/ExternalForwardingMachinesTab";
import Box from "@material-ui/core/Box";
import {MachineDataPushTargetModel} from "../../../stores/MachineDataPushTargetStore";

type MachineDataPushTargetFormProps = {
  model: MachineDataPushTargetModel
}

export const ForwardingTargetsExternalForm: React.FunctionComponent<MachineDataPushTargetFormProps> = observer(({ model }) => {

    const forwardingInterfaceOptions = React.useMemo(() => {
        return [{
            label: t`Machine Data`,
            value: 'machine_data'
        }, {
            label: t`Order Data`,
            value: 'order_data'
        }];
    }, []);

    const forwardingInterfaceDefaultTab = React.useMemo(() => {
        
        return forwardingInterfaceOptions[
            (!model.viewModel.order_path && !model.viewModel.update_order_path) ? 0 : 1
        ].value;
         
    }, [forwardingInterfaceOptions, model.viewModel.order_path]);

    const [selectedForwardingInterface, setSelectedForwardingInterface] = React.useState<string>(forwardingInterfaceDefaultTab);

    const shownTabs = React.useMemo(() => {
        const tabs = [{
            label: t`Endpoints`,
            component: <ExternalForwardingEndpointsTab hideMachineData={selectedForwardingInterface === 'order_data'}/>,
            defaultTab: true,
            disabled: false
        }];

        if (selectedForwardingInterface === 'machine_data') {
            tabs.push({
                label: t`Machines`,
                component: <ExternalForwardingMachinesTab/>,
                defaultTab: false,
                disabled: model.isNew
            });
        }
        
        return tabs;

    }, [model.isNew, selectedForwardingInterface]);

    return(
        <ModelForm model={model} suppressMakeCopy suppressImportExport>
            <ModelInput name={'name'} />
            <ModelInput name={'base_url'} />
            <SelectField
                label={t`Forwarding Interface`}
                onChange={(name, value) => { setSelectedForwardingInterface(value); }}
                value={selectedForwardingInterface}
                options={forwardingInterfaceOptions}
            />
            <Box mt={1}>
                <TabsContainer
                    variant="scrollable"
                    scrollButtons="auto"
                    tabs={shownTabs}
                />
            </Box>
        </ModelForm>
    )
})