import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {action, computed} from "mobx";

// regex for number or number range
const rNumRange = /^(?:\d*|\d+[-]+\d+)\s?(?:,(?:\s?)(?:\d+[-]+\d+|\d*))*$/i;
export const isNumRange = (input:string) => {
    return rNumRange.test(input);
}

@model({
    transportLayer: "/api/error_filters",
    permissionTarget: "ErrorFilter",
    routingInfo: {
        list: '/settings/data_filtering',
        create: '/settings/data_filtering/create',
        read: '/settings/data_filtering/:id/read',
        update: '/settings/data_filtering/:id/edit'
    }
})

export class ErrorFilterModel extends Model {
    @attribute({
        label: t`Rule Name`,
        validation: yup.string().required(t`Rule name is required`)
    })
    name: string = '';

    @attribute({
        label: t`Error Codes`,
        validation: yup.string().required(t`Error code is required`)
            .test('valid-error-code', t`Error code must be valid`, (val) => {
            return isNumRange(val)
        })
    })
    error_codes: string = ''

    @attribute({
        label: t`Behaviour`,
        validation: yup.string().required(t`A behaviour must be selected`)
    })
    behaviour: string = 'ignore'

    @attribute( {
        label: t`Replacement Name`,
        validation: yup.string().when('behaviour', {
            is: 'replace',
            then: yup.string().required(t`Replacement Name is required when selected Behaviour is Rename`)
        })
    })
    replace_name: string = ''

    @attribute( {
        label: t`Group Code`,
        validation: yup.string().required(t`Group Code is required`)
    })
    group_code: string = ''

    @attribute()
    enabled: boolean = true

    @attribute()
    filter_target_type: 'MachineType' | 'MachineGroup' = 'MachineGroup' ;

    @attribute()
    filter_target_id: number = -1

    @action
    async toggle() {
        return await fetch(`${ErrorFilterStore.transportLayer.base}/${this.id}/toggle`, {method: "PUT"});
    }

    @computed
    get isReplaceFilter() {
       return this.viewModel.behaviour === "replace"
    }

    constructor() {
        super();
        super.setup();
    }
}

export const ErrorFilterStore = ErrorFilterModel.store as unknown as DataStore<ErrorFilterModel>