import {attribute, DataStore, model, Model} from '@rx-suite/data';

import {t} from "@lingui/macro";
import {computed} from "mobx";

@model({
    eager: true,
    transportLayer: "/api/machine_types",
    routingInfo: {
        create: "/settings/machine_types/create",
        update: "/settings/machine_types/:id/edit",
        read: "/settings/machine_types/:id"
    }
})
export class MachineTypeModel extends Model {
    @attribute()
    id: number = -1;

    @attribute({ label: t`Name`})
    name: string = "";

    @attribute({ label: t`Display Name`})
    display_name: string = "";

    @attribute({ label: t`Category`})
    category: string = "";

    @attribute()
    image_url: string = "";

    @attribute()
    machine_state_enabled: boolean = false;

    @attribute()
    job_state_enabled: boolean = false;

    @attribute()
    error_enabled: boolean = false;

    @attribute()
    maintenance_enabled: boolean = false;

    @attribute()
    process_data_enabled: boolean = false;

    @attribute()
    event_data_enabled: boolean = false;

    @attribute()
    calibration_data_enabled: boolean = false;

    @computed
    get isBoxCoater(): boolean {
        return this.category === 'box_coater';
    }

    constructor() {
        super();
        super.setup();
    }
}

export const MachineTypeStore = MachineTypeModel.store as DataStore<MachineTypeModel>;