class ProcessArchiveCreatesJob < ApplicationJob
  def perform
    ArchiveTask.creates.in_batches(of: 1000) do |batch|
      inserts = batch.reject do |task|
        ActiveRecord::Base.connected_to(shard: :archive, role: :reading) { task.target_class.exists?(task.target_attributes["id"]) }
      end
      grouped_create_tasks = inserts.group_by { |ct| ct.target_class }
      grouped_create_tasks.each do |klass, tasks|
        attributes = tasks.map(&:target_attributes)
        begin
          insert_all = ActiveRecord::InsertAll.new(klass, attributes.compact, on_duplicate: :raise)
          ActiveRecord::Base.connected_to(shard: :archive, role: :writing) do
            ActiveRecord::Base.connection.execute(insert_all.send(:to_sql))
          end
        rescue StandardError => e
          Rails.logger.error e
        end
      end
      batch.delete_all
    end
  end
end