module KpiTableHandler
  module Base
    class MssqlKpiTableDatabaseHandler
      include KpiHelpers
      attr_accessor :use_offset

      def initialize(use_offset)
        self.use_offset = use_offset
      end

      def from_sub_query(table, base_select, base_group)
        table.select(base_select + [select_sub_query]).group(base_group + [group_sub_query])
      end

      def select_sub_query
        if use_offset
          # StringScanner in ActiveRecord::ConnectionsAdapter::SQLServer::Utils has a hard time parsing strings with end of line characters within so we squish the sql string.
          string = <<~SQL
          CAST(
              CASE
                  WHEN datediff(minute, dateadd(minute, -30, time), dateadd(hour, datediff(hour, 0, time), 0)) = 0
                      then time 
                  ELSE
                      dateadd(minute, -30, time)
              END AS DATETIME
          ) AS time
          SQL
          string.squish
        else
          'dateadd(hour, datediff(hour, 0, time), 0) as time'
        end
      end

      def group_sub_query
        if use_offset
          # StringScanner in ActiveRecord::ConnectionsAdapter::SQLServer::Utils has a hard time parsing strings with end of line characters within so we squish the sql string.
          string = <<~SQL
          CASE
              WHEN datediff(minute, dateadd(minute, -30, time), dateadd(hour, datediff(hour, 0, time), 0)) = 0
                  THEN time 
              ELSE
                  dateadd(minute, -30, time)
          END
          SQL
          string.squish
        else
          'dateadd(hour, datediff(hour, 0, time), 0)'
        end
      end

      def group_kpi_table_by_time_frame(sub_query, timeframe, timeframe_select, timeframe_group, start_time)
        select_query = timeframe_select
        group_query = timeframe_group
        case timeframe
        when Timeframe::DAY_BY_DAY
          select_query << "dateadd(day, datediff(day, 0, (time AT TIME ZONE 'UTC' AT TIME ZONE '#{ENV['TZ_NAME']}')), 0) as time"
          group_query << "dateadd(day, datediff(day, 0, (time AT TIME ZONE 'UTC' AT TIME ZONE '#{ENV['TZ_NAME']}')), 0)"
        when Timeframe::WEEK_BY_WEEK
          ###### NEW
          # 1- the date difference between date at time 0 and time in column
          # 2- default date week is on a Monday, we are calculating for a Friday, so add 3 days
          #   6 january (Friday): day 44930, divided by 7 is 6417.57
          #   9 january (Monday): day 44933, divided by 7 is 6419
          #   so (44930 + 3) / 7 = 6419 (round number)
          # 3- divide by 7, this gives us the week number for the bucket
          # 4- dateadd part is the transform back into a date, so reverse order operation
          days_since_monday = ((start_time - start_time.monday) / 1.day).floor
          select_query << "dateadd(d, 0, ((datediff(d, 0, time AT TIME ZONE 'UTC' AT TIME ZONE '#{ENV['TZ_NAME']}') - #{days_since_monday}) / 7) * 7 + #{days_since_monday}) as time"
          group_query << "dateadd(d, 0, ((datediff(d, 0, time AT TIME ZONE 'UTC' AT TIME ZONE '#{ENV['TZ_NAME']}') - #{days_since_monday}) / 7) * 7 + #{days_since_monday}) "

          #select_query << "dateadd(week, datediff(week, 0, (time AT TIME ZONE 'UTC' AT TIME ZONE '#{ENV['TZ_NAME']}')), -1) as time"
          #group_query << "dateadd(week, datediff(week, 0, (time AT TIME ZONE 'UTC' AT TIME ZONE '#{ENV['TZ_NAME']}')), -1)"
        when Timeframe::ALL
        else
          return sub_query
        end
        from_sub_query = sub_table_to_from_string(sub_query)
        table = sub_query.klass
        table.select(select_query).from(from_sub_query).group(group_query)
      end
    end
  end
end