module MachineKpiCalculator
  class AbortTrends < TopAborts

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = AbortTrends.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :abort_count,
          handler: KpiTableHandler::MachineAbortCountKpiHandler,
          params: {
          }
        }
      ]
    end

    def build_results
      abort_codes = group_codes(data[:abort_count])

      # get top aborts from abort codes
      top_aborts = extract_top_x(abort_codes, 5)
      top_aborts = top_aborts.map {|e| e[:code]} # We only need the code of the top 5 aborts

      results = {}
      top_aborts.each do |abort|
        results[abort] = {}
      end

      data[:abort_count].each do |time, abort_data|
        results.keys.each { |abort_code| results[abort_code][time] = 0 }
        abort_data.each do |abort_code, val|
          next unless top_aborts.include?(abort_code)
          results[abort_code][time] = val
        end
      end

      resolved_abort_results = {}
      results.each do |code, time_hash|
        resolved_abort_results[resolve_abort_code(code)] ||= {}
        resolved_abort_results[resolve_abort_code(code)].merge!(time_hash) {|k, val1, val2| val1 + val2}
      end
      results
    end

    def build_results_per_machine
      data[:abort_count]
    end
  end
end