module MachineKpiCalculator
  class BoxCoaterReportingCategoryBreakdown < MachineKpiCalculator
    include KpiHelpers
    include BucketCalculator

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: {})
        kpi = BoxCoaterReportingCategoryBreakdown.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :time_in_reporting_category_breakdown,
          handler: :time_in_reporting_category_breakdown,
          params: {}
        }
      ]
    end

    def as_percent?
      options[:as_percent]
    end

    def time_in_reporting_category_breakdown
      time_in_category = time_buckets(start_time, end_time, timeframe, bucket_default_val: {
        unknown: 0,
        programmed_stop: 0,
        breakdown_machine: 0,
        breakdown_utility: 0,
        maintenance_usual_pm: 0,
        maintenance_usual_daily: 0,
        idle_time_open: 0,
        idle_time_wait: 0,
        production_setup: 0,
        speed_loss: 0
      })
      tracking_stations = ensure_tracking_stations
      MachineKpi::EerKpiCalculator.timeline_calculator(start_time, end_time, machine_ids, true) do |timeline, event_indices_within_timeline, shift_start_time, shift_end_time|
        next if event_indices_within_timeline.empty?

        event_indices_within_timeline.each do |index|
          event = timeline[index]
          next if event.event_type == "engineering_lockout"
          event_duration = EerKpiCalculator.event_duration_in_shift(event, shift_start_time, shift_end_time)
          duration = calculate_duration(event, event_duration, shift_start_time, tracking_stations)
          next if duration == 0
          category = event.reporting_category&.to_sym || :unknown
          if timeframe_all?
            category = :unknown unless time_in_category.has_key?(category)
            time_in_category[category] += duration
          else
            category = :unknown unless time_in_category[time_bucket_index(shift_start_time)].has_key?(category)
            time_in_category[time_bucket_index(shift_start_time)][category] += duration
          end
        end
      end
      time_in_category
    end

    def ensure_tracking_stations
      if Rails.env.test?
        Machine.where(track_eer_metrics: true).map do |eer_machine|
          {
            rx_data_machine_id: eer_machine.id,
            machine_sn: eer_machine.sn,
            door_open_max_time: 300,
            door_closed_max_time: 1500
          }
        end
      else
        RxModule::Communicator.call_module_method_as_module("rx_eer", "/api/eer_tracking_stations", :get)[:models]
      end
    end

    def calculate_duration(event, duration, shift_start_time, tracking_stations)
      machine = event.machine
      eer_tracking_station = tracking_stations.find { |station| station[:rx_data_machine_id] == machine.id }
      duration_to_remove = if event.event_type == "door_open"
        eer_tracking_station[:door_open_max_time]
      else
        recipe = BoxCoaterRecipe.where(recipe_code: event.recipe).first
        if recipe
          recipe[:processing_time]
        else
          eer_tracking_station[:door_closed_max_time]
        end
      end

      if event.time < shift_start_time
        if shift_start_time - event.time < duration_to_remove
          duration_to_remove -= shift_start_time - event.time
        else
          duration_to_remove = 0
        end
      end

      duration -= duration_to_remove

      unless duration > 0
        duration = 0
      end
      duration
    end

    def build_results
      buckets = data[:time_in_reporting_category_breakdown]

      if timeframe_all?
        if Rails.env.test? || RxModule::Communicator::Shifts.shifts_between(start_time, end_time)[:models].blank?
          time_in_shift = (end_time - start_time)
        else
          time_in_shift = RxModule::Communicator::Shifts.active_time_between(start_time, end_time) * machine_ids.size
        end
        buckets[:active_time] = time_in_shift * machine_ids.size
      else
        buckets.each do |time, value|
          end_of_bucket = time + timeframe_length
          if Rails.env.test? || RxModule::Communicator::Shifts.shifts_between(time, end_of_bucket)[:models].blank?
            time_in_shift = timeframe_length * machine_ids.size
          else
            time_in_shift = RxModule::Communicator::Shifts.active_time_between(time, end_of_bucket) * machine_ids.size
          end
          active_time = time_in_shift * machine_ids.size
          buckets[time][:active_time] = active_time
        end
      end
      buckets
    end

    def percent_buckets(row, m_count)
      if timeframe_all?
        row.each do |reporting_category, duration|
          if row[:active_time][:count] == 0
          else
            row[reporting_category][:percent] = Tools.percentage_maker(duration[:count], row[:active_time][:count], 2)
          end
        end
      else
        row.each do |time, value_hash|
          value_hash.each do |reporting_category, duration|
            if value_hash[:active_time][:count] == 0
              row[time][reporting_category][:percent] = 0
            else
              row[time][reporting_category][:percent] = Tools.percentage_maker(duration[:count], value_hash[:active_time][:count], 2)
            end
          end
        end
      end
    end

    def build_results_per_machine
      data[:time_in_reporting_category_breakdown]
    end
  end
end
