module MachineKpiCalculator
  class BoxCoaterYield < MachineKpiCalculator
    include KpiHelpers
    include BucketCalculator

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: {})
        kpi = BoxCoaterYield.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :yield_between,
          handler: :yield_between,
          params: {}
        }
      ]
    end

    def aggregate_to_one_value?
      !!options[:aggregate_to_one_value]
    end

    def yield_between
      yields = time_buckets(start_time, end_time, timeframe, bucket_default_val: {
        value: 0,
        yield_in_this_timeframe: 0
      })
      EerYield.yields_between(start_time, end_time, machine_ids).each do |eer_yield|
        date = time_bucket_index(eer_yield.date)
        yields.deep_merge!(
          {
            date => {
              value: eer_yield.value,
              yield_in_this_timeframe: 1
            }
          }) { |k, val1, val2| val1 + val2 }
      end
      yields.each do |key, value|
        next yields[key] = 0 if value[:yield_in_this_timeframe] == 0
        yields[key] = value[:value].to_f / value[:yield_in_this_timeframe].to_f
      end
      yields
    end

    def build_results
      return data[:yield_between] unless aggregate_to_one_value?

      aggregate_to_one_value(data[:yield_between])
    end

    def build_results_per_machine
      data[:yield_between]
    end

    def format_results
      @results.each do |time, value|
        @results[time] = {percent: value}
      end
    end
  end
end
