# == Schema Information
#
# Table name: abort_filters
#
#  id                 :bigint           not null, primary key
#  behaviour          :integer
#  enabled            :boolean          default(TRUE)
#  filter_target_type :string(4000)
#  group_code         :string(4000)
#  name               :string(4000)
#  regexps            :string(4000)
#  replace_name       :string(4000)
#  system_default     :boolean          default(FALSE)
#  created_at         :datetime         not null
#  updated_at         :datetime         not null
#  filter_target_id   :bigint
#
# Indexes
#
#  abort_filter_target_type_id           (filter_target_type,filter_target_id)
#  abort_group_code                      (group_code) UNIQUE
#  index_abort_filters_on_filter_target  (filter_target_type,filter_target_id)
#
class AbortFilter < ApplicationRecord
  belongs_to :filter_target, polymorphic: true

  enum behaviour: [:ignore, :replace, :use_as_is]

  validates :group_code, uniqueness: true

  def should_broadcast?
    true
  end

  def is_ignore_filter?
    behaviour == 'ignore'
  end

  def self.calculate_filter_for_job_state(job_state)
    machine = job_state.machine

    abort_reason = job_state.raw_abort_reason
    return nil if abort_reason.nil?

    filter = nil

    # If the source machine has no type, no way there's a filter
    if machine.has_machine_type?
      AbortFilter.where(filter_target_type: :MachineType, filter_target_id: machine.machine_type_id, enabled: true).find_each do |f|
        regexps = f.regexps.split(',')
        regexps.each do |regex_def|
          regex = Regexp.new(regex_def, Regexp::IGNORECASE)

          unless regex.match(abort_reason).nil?
            filter = f
            break
          end
        end
        # as soon as we have a match, escape
        if filter
          break
        end
      end
    end

    filter
  end
end
