# == Schema Information
#
# Table name: archive_tasks
#
#  id                           :bigint           not null, primary key
#  method                       :integer
#  retry_count                  :integer          default(0)
#  serialized_target_attributes :binary(214748364
#  serialized_target_class      :binary(214748364
#  created_at                   :datetime         not null
#  updated_at                   :datetime         not null
#
# Indexes
#
#  index_archive_tasks_on_method  (method)
#
class ArchiveTask < ApplicationRecord
  enum method: [:creator, :updater]

  scope :updates, -> { where(method: :updater) }
  scope :creates, -> { where(method: :creator) }

  def should_archive?
    false
  end

  def self.queue_task(method, model)
    ArchiveTask.create(method: method, serialized_target_attributes: Marshal.dump(model.attributes), serialized_target_class: Marshal.dump(model.class))
  end

  def target_attributes
    Marshal.load(serialized_target_attributes)
  end

  def target_class
    Marshal.load(serialized_target_class)
  end

  def self.queue_update(model)
    queue_task(:updater, model)
  end

  def self.queue_create(model)
    queue_task(:creator, model)
  end

  def self.queue_touch(model)
    queue_task(:updater, model)
  end
end
