# == Schema Information
#
# Table name: box_coater_batches
#
#  id                  :bigint           not null, primary key
#  crystal_life        :string(4000)
#  empty_holes_count   :integer
#  lens_count          :integer
#  time                :datetime         not null
#  created_at          :datetime         not null
#  updated_at          :datetime         not null
#  batch_id            :string(4000)
#  box_coater_event_id :bigint
#  machine_id          :bigint           not null
#
# Indexes
#
#  index_box_coater_batches_on_box_coater_event_id  (box_coater_event_id)
#  index_box_coater_batches_on_machine_id           (machine_id)
#
# Foreign Keys
#
#  fk_rails_...  (box_coater_event_id => box_coater_events.id) ON DELETE => nullify
#
class BoxCoaterBatch < ApplicationRecord
  belongs_to :machine
  has_one :box_coater_event

  def self.find_existing_batch(batch_id, machine, time)
    # Search for a batch that matches the batch_id in a 8 hour span
    batch = BoxCoaterBatch.where(machine: machine, batch_id: batch_id)
                  .where(BoxCoaterBatch.arel_table[:time].lteq(time + 4.hours).and(BoxCoaterBatch.arel_table[:time].gteq(time - 4.hours)))
                  .first

    return batch unless batch.nil?

    # If no batch matches the id, try to find an orphan batch close to the same time
    BoxCoaterBatch.where(machine: machine, batch_id: nil)
                  .where(BoxCoaterBatch.arel_table[:time].lteq(time + 30.minutes).and(BoxCoaterBatch.arel_table[:time].gteq(time - 30.minutes)))
                  .order(time: :desc)
                  .first
  end
end
