module Pushable
  extend ActiveSupport::Concern

  def broadcast(async: false)
    # We're converting to json, then parsing it because
    # to_json is overridden to render a model's jbuilder document.
    # PushDataJob uses RxModule::Communicator to pass the message to the push target, and communicator
    # accepts a hash, not a string
    method = if async
      PushDataJob.method(:perform_later)
    else
      PushDataJob.method(:perform_now)
    end
    method.call(self.class.name.underscore, JSON.parse(to_json))
  end

  def broadcast_destroy(async: false)
    method = if async
      PushDataJob.method(:perform_later)
    else
      PushDataJob.method(:perform_now)
    end
    method.call(self.class.name.underscore, {id: id, destroyed: true}.as_json)
  end

  # machines have the option to opt-out of broadcasting their data
  def broadcast_machine_data(machine, async: false)
    if machine.push_target_enabled
      broadcast(async: async)
    end
  end
end
