# == Schema Information
#
# Table name: kpi_machine_abort_counts
#
#  id         :bigint           not null, primary key
#  count      :integer          default(0)
#  group_code :string(4000)     not null
#  time       :datetime         not null
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  machine_id :bigint
#
# Indexes
#
#  index_kpi_machine_abort_counts_on_machine_id  (machine_id)
#  kpi_machine_abort_count_uniq_time_code        (time,machine_id,group_code) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (machine_id => machines.id) ON DELETE => cascade
#
class KpiMachineAbortCount < ApplicationRecord
  include KpiHelpers

  belongs_to :machine

  def should_archive?
    false
  end

  def self.cache_job_state(job_state)
    return unless job_state.is_aborted?

    group_code = if job_state.has_filter?
                   job_state.abort_filter.group_code
                 else
                   "other"
                 end

    cache_entry = KpiHelpers.get_kpi_cache_entry(KpiMachineAbortCount, job_state.time, { machine_id: job_state.machine.id, group_code: group_code})

    if cache_entry.nil?
      cache_entry = KpiMachineAbortCount.create(
        time: KpiHelpers.kpi_bucket_time(job_state.time),
        machine_id: job_state.machine.id,
        group_code: group_code,
        count: 1
      )
    else
      cache_entry.update(count: cache_entry.count += 1)
    end

    cache_entry
  end

  def self.build_default_cache_entry(bucket_time, machine_id, group_code)
    {
      group_code: group_code,
      count: 0,
      time: bucket_time,
      machine_id: machine_id,
      created_at: Time.zone.now,
      updated_at: Time.zone.now
    }
  end

  def self.abort_group_code(abort)
    if abort.has_filter?
      group_code = abort.abort_filter.group_code
    else
      group_code = "other"
    end
    group_code
  end

  def self.backwards_cache_entry_calculation(entry)
    # TODO: Modify function to be able to do multiple buckets
    start_time = entry[:time]
    end_time = start_time + 30.minutes
    machine_id = entry[:machine_id]

    cache_entries = []
    aborts = JobState.where(machine_id: machine_id, state: "aborted").where(JobState.arel_table[:time].gteq(start_time).and(JobState.arel_table[:time]).lt(end_time))

    if aborts.count == 0
      cache_entries << build_default_cache_entry(start_time,  machine_id, 'none')
    else
      aborts.find_each do |abort|
        group_code = abort_group_code(abort)

        entry = cache_entries.find{|a| a[:group_code] == group_code}

        if entry.nil?
          entry = build_default_cache_entry(start_time,  machine_id, group_code)
          cache_entries << entry
        end

        entry[:count] += 1
      end
    end

    cache_entries
  end
end
