# == Schema Information
#
# Table name: kpi_routing_kickouts
#
#  id                                 :bigint           not null, primary key
#  fail_fetch_processes               :integer          default(0)
#  failed_to_synchronize              :integer          default(0)
#  fetch_job_inf_failed               :integer          default(0)
#  manual_reject                      :integer          default(0)
#  marked_dead                        :integer          default(0)
#  no_processes                       :integer          default(0)
#  no_processes_at_non_start          :integer          default(0)
#  no_valid_path                      :integer          default(0)
#  other                              :integer          default(0)
#  process_aborted                    :integer          default(0)
#  received_invalid_process           :integer          default(0)
#  rework_complete                    :integer          default(0)
#  routed_while_waiting_other_process :integer          default(0)
#  time                               :datetime         not null
#  time_sync_error                    :integer          default(0)
#  created_at                         :datetime         not null
#  updated_at                         :datetime         not null
#  machine_id                         :bigint
#
# Indexes
#
#  index_kpi_routing_kickouts_on_machine_id   (machine_id)
#  kpi_routing_kickout_uniq_time_per_machine  (time,machine_id) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (machine_id => machines.id) ON DELETE => cascade
#
class KpiRoutingKickout < ApplicationRecord
  belongs_to :machine
  include DataHelpers
  include KpiHelpers

  def should_archive?
    false
  end

  def self.cache_job_state(job_state)
    return if job_state.scrap_reason.nil? || job_state.scrap_reason == ''

    cache_entry = KpiHelpers.get_kpi_cache_entry(KpiRoutingKickout, job_state.time, { machine_id: job_state.machine_id})
    column_name = get_column_name(job_state)

    if cache_entry.nil?
      cache_entry = KpiRoutingKickout.create(time: KpiHelpers.kpi_bucket_time(job_state.time), machine_id: job_state.machine_id, column_name => 1)
    else
      cache_entry.update(column_name => cache_entry[column_name] += 1)
    end

    cache_entry
  end

  def self.get_column_name(job_state)
    return 'other' if job_state.scrap_reason.nil?
    scrap_reason = job_state.scrap_reason.to_sym
    return 'other' unless ROUTING_KICKOUT_REASONS.has_key? scrap_reason
    ROUTING_KICKOUT_REASONS[scrap_reason][:database_key]
  end

  def self.backwards_cache_entry_calculation(entry)
    start_time = entry[:time]
    end_time = start_time + 30.minutes
    machine_id = entry[:machine_id]

    reason_hash = {}
    ROUTING_KICKOUT_REASONS.each_value {|val| reason_hash[val[:database_key]] = 0}
    job_states = JobState.where(machine_id: machine_id).where(JobState.arel_table[:time].gteq(start_time).and(JobState.arel_table[:time]).lt(end_time))
    job_states.each do |job_state|
      sym_scrap_reason = get_column_name(job_state)
      if ROUTING_KICKOUT_REASONS.has_key? sym_scrap_reason
        db_key = ROUTING_KICKOUT_REASONS[sym_scrap_reason][:database_key]
        reason_hash[db_key] += 1
      else
        reason_hash["other"] += 1
      end
    end

    [
      reason_hash.merge!(
        {
          time: start_time,
          machine_id: machine_id.to_i,
          created_at: Time.zone.now,
          updated_at: Time.zone.now
        }
      )
    ]
  end
end
