module ReportTargetValues
  extend ActiveSupport::Concern
  include KpiHelpers

  class_methods do
    def use_uptime_target
      parameter(
        :uptime_target,
        "Uptime Target (%)",
        "The uptime target (%) used in the overview chart.",
        :integer,
        min: 1,
        max: 100,
        default: default_uptime_target)
    end

    def use_utilization_target
      parameter(
        :utilization_target,
        "Utilization Target (%)",
        "The utilization target (%) used in the overview chart.",
        :integer,
        min: 1,
        max: 100,
        default: default_utilization_target)
    end

    def use_oee_target
      parameter(
        :oee_target,
        "OEE Target (%)",
        "The oee target (%) used in the overview chart.",
        :integer,
        min: 1,
        max: 100,
        default: default_oee_target)
    end

    def default_uptime_target
      ProductionSetting.instance.machine_uptime_target
    end

    def default_utilization_target
      ProductionSetting.instance.machine_utilization_target
    end

    def default_oee_target
      ProductionSetting.instance.machine_oee_target
    end
  end

  def uptime_target
    return self.default_uptime_target if @parameters[:uptime_target].nil?
    @parameters[:uptime_target]
  end

  def utilization_target
    return self.default_utilization_target if @parameters[:utilization_target].nil?
    @parameters[:utilization_target]
  end

  def oee_target
    return self.default_oee_target if @parameters[:oee_target].nil?
    @parameters[:oee_target]
  end
end