module ReportComponents
  class BoxCoaterTimeInReportingCategoryBreakdownPie < ReportComponent

    include ReportComponentHelpers
    include KpiHelpers

    def component_id
      'box_coater_time_reporting_category_breakdown'
    end

    def component_type
      'pie'
    end

    def reporting_category_colors
      {
        "Programmed Production Stop" => '#598C5E',
        "Breakdown" => '#6ECBA6',
        "Maintenance" => '#68D7DF',
        "Set-up/Changeover" => '#3AAFB8',
        "Speed Loss" => '#40E052',
        "Unknown" => '#ABB2B9',
        "Production Time" => "#008FFB"
      }
    end

    def production_time_key
      "Production Time"
    end

    def generate(args)
      # Pie chart aggregated by timeframe, so only one bucket
      res = MachineKpi.time_in_reporting_category_breakdown(start_time, end_time, Timeframe::ALL, machine_ids, options: args.merge!({addons: [:as_percent]}))
      bucket = MachineKpiCalculator::EerKpiCalculator.reporting_categories_mapping(res)
      production_time_bucket = bucket.delete(production_time_key)

      labels = []
      # This doesnt make sense, we are removing time from production time which is one of the bucket, and then we also remove production time from itself.
      series = bucket.map do |reporting_Category, value|
        labels << reporting_Category
        production_time_bucket[:count] -= value[:count]
        production_time_bucket[:percent] -= value[:percent].to_f.round(2)
        value[:percent].to_f.round(2)
      end

      series << production_time_bucket[:percent].to_f.round(2)
      labels << production_time_key
      {
        series: series,
        labels: labels,
        colors: labels.map {|label| reporting_category_colors[label]}
      }
    end
  end
end
